##
##  nsq.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2022 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package version
%define       V_nsq_base 1.2.1
%define       V_nsq_snap 20220828

#   package information
Name:         nsq
Summary:      Real-Time Distributed Messaging Platform
URL:          http://nsq.io/
Vendor:       Matt Reiferson, Jehiah Czebotar
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Networking
License:      MIT
Version:      %{V_nsq_base}.%{V_nsq_snap}
Release:      20220828

#   list of sources
Source0:      http://download.openpkg.org/components/versioned/nsq/nsq-%{V_nsq_snap}.tar.xz
Source1:      rc.nsq
Source2:      nsq.txt

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, go
PreReq:       OpenPKG, openpkg >= 20160101

%description
    NSQ is a realtime distributed messaging platform designed to operate
    at scale, handling billions of messages per day. It promotes
    distributed and decentralized topologies without single points of
    failure, enabling fault tolerance and high availability coupled with
    a reliable message delivery guarantee.

%track
    prog nsq:release = {
        version   = %{V_nsq_base}
        url       = https://github.com/nsqio/nsq/releases
        regex     = v(1\.[0-9]\.\d+)\.tar\.gz
    }
    prog nsq:snapshot = {
        version   = %{V_nsq_snap}
        url       = http://download.openpkg.org/components/versioned/nsq/
        regex     = nsq-(__VER__)\.tar\.xz
    }

%prep
    %setup -q -n nsq

%build
    #   build program
    export GOPATH=`pwd`
    cd src/github.com/nsqio/nsq
    %{l_make} %{l_mflags} GOFLAGS="-v"

%install
    #   create directory hierarchy
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/sbin \
        $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d \
        $RPM_BUILD_ROOT%{l_prefix}/etc/nsq \
        $RPM_BUILD_ROOT%{l_prefix}/var/nsq/data \
        $RPM_BUILD_ROOT%{l_prefix}/var/nsq/log \
        $RPM_BUILD_ROOT%{l_prefix}/var/nsq/run

    #   install program
    (   cd src/github.com/nsqio/nsq
        %{l_make} %{l_mflags} install \
            DESTDIR=$RPM_BUILD_ROOT \
            BINDIR=%{l_prefix}/sbin
    ) || exit $?

    #   install default configuration
    for name in `grep "^<file" %{SOURCE nsq.txt} | sed -e 's;^.*name=";;' -e 's;".*$;;'`; do
        (echo ""; cat %{SOURCE nsq.txt}; echo "") |\
            sed -e "1,/^<file name=\"$name\">/d" -e "/<\/file>/,\$d" >$name
        %{l_shtool} install -c -m 644 %{l_value -s -a} \
            $name $RPM_BUILD_ROOT%{l_prefix}/etc/nsq/
    done

    #   install run-command script
    %{l_shtool} install -c -m 755 %{l_value -s -a} \
        %{SOURCE rc.nsq} $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d/

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%config %{l_prefix}/etc/nsq/*' \
        '%attr(-,%{l_rusr},%{l_rgrp}) %{l_prefix}/var/nsq/*'

%files -f files

%clean

%post
    #   after upgrade, restart service
    [ $1 -eq 2 ] || exit 0
    eval `%{l_rc} nsq status 2>/dev/null`
    [ ".$nsq_active" = .yes ] && %{l_rc} nsq restart
    exit 0

%preun
    #   before erase, stop service and remove log files
    [ $1 -eq 0 ] || exit 0
    %{l_rc} nsq stop 2>/dev/null
    rm -rf $RPM_INSTALL_PREFIX/var/nsq/log/* >/dev/null 2>&1 || true
    rm -rf $RPM_INSTALL_PREFIX/var/nsq/run/* >/dev/null 2>&1 || true
    exit 0

